+++
title = "Mass Spring Damper Systems"
author = ["Dehaeze Thomas"]
draft = false
+++

Tags
: [Tuned Mass Damper]({{< relref "tuned_mass_damper.md" >}})


## One Degree of Freedom {#one-degree-of-freedom}


### Model and equation of motion {#model-and-equation-of-motion}

Let's consider [Figure 1](#figure--fig:mass-spring-damper-system) where:

-   \\(m\\) is the mass in [kg]
-   \\(k\\) is the spring stiffness in [N/m]
-   \\(c\\) is the damping coefficient in [N/(m/s)]
-   \\(F\\) is the actuator force in [N]
-   \\(F\_d\\) is external force applied to the mass in [N]
-   \\(w\\) is ground motion
-   \\(x\\) is the absolute mass motion

<a id="figure--fig:mass-spring-damper-system"></a>

{{< figure src="/ox-hugo/mass_spring_damper_system.png" caption="<span class=\"figure-number\">Figure 1: </span>Mass Spring Damper System" >}}

Transmissibility:

\begin{equation}
  \frac{x}{w}(s) = \frac{c s + k}{m s^2 + c s + k} = \frac{2 \xi \frac{s}{\omega\_0} + 1}{\frac{s^2}{\omega\_0^2} + 2 \xi \frac{s}{\omega\_0} + 1}
\end{equation}

Compliance:

\begin{equation}
  \frac{x}{F}(s) = \frac{x}{F\_d}(s) = \frac{1}{m s^2 + c s + k} = \frac{1/k}{\frac{s^2}{\omega\_0^2} + 2 \xi \frac{s}{\omega\_0} + 1}
\end{equation}

with:

-   \\(\omega\_0 = \sqrt{k/m}\\) the natural frequency in [rad/s]
-   \\(\xi = \frac{1}{2} \frac{c}{\sqrt{km}}\\) the damping ratio [unit-less]

A quality factor \\(Q\\) can also be defined:

\begin{equation}
Q = \frac{1}{2\xi}
\end{equation}

This corresponds to the amplification at the natural frequency \\(\omega\_0\\).


### Matlab model {#matlab-model}

```matlab
%% Mechanical properties
m = 1; % Mobile mass [kg]
k = 1e6; % stiffness [N/m]
xi = 0.1; % Modal Damping

c = 2*xi*sqrt(k*m);
```

```matlab
%% Compliance: Transfer function from F [N] to x [m]
Gf = 1/(m*s^2 + c*s + k);

%% Transmissibility: Transfer function from w [m] to x [m]
Gw = (c*s + k)/(m*s^2 + c*s + k);
```

<a id="figure--fig:mass-spring-damper-1dof-compliance"></a>

{{< figure src="/ox-hugo/mass_spring_damper_1dof_compliance.png" caption="<span class=\"figure-number\">Figure 2: </span>1dof Mass spring damper system - Compliance" >}}

<a id="figure--fig:mass-spring-damper-1dof-transmissibility"></a>

{{< figure src="/ox-hugo/mass_spring_damper_1dof_transmissibility.png" caption="<span class=\"figure-number\">Figure 3: </span>1dof Mass spring damper system - Transmissibility" >}}


## Two Degrees of Freedom {#two-degrees-of-freedom}


### Model and equation of motion {#model-and-equation-of-motion}

Consider the two degrees of freedom mass spring damper system of [Figure 4](#figure--fig:mass-spring-damper-2dof).

<a id="figure--fig:mass-spring-damper-2dof"></a>

{{< figure src="/ox-hugo/mass_spring_damper_2dof.png" caption="<span class=\"figure-number\">Figure 4: </span>2 DoF Mass Spring Damper system" >}}

We can write the Newton's second law of motion to the two masses:

\begin{align}
m\_2 s^2 x\_2 &= F\_2 + (k\_2 + c\_2 s) (x\_1 - x\_2) \\\\
m\_1 s^2 x\_1 &= F\_1 + (k\_1 + c\_1 s) (x\_0 - x\_1)  + (k\_2 + c\_2 s) (x\_2 - x\_1)
\end{align}

The goal is to have \\(x\_1\\) and \\(x\_2\\) as a function of \\(F\_1\\), \\(F\_2\\) and \\(x\_0\\).

When, we have:

\begin{equation}
\boxed{x\_1 = \frac{(m\_2 s^2 + c\_2 s + k\_2) F\_1 + (k\_1 + c\_1 s) (m\_2 s^2 + c\_2 s + k\_2) x\_0  + (k\_2 + c\_2 s) F\_2}{(m\_1 s^2 + c\_1 s + k\_1)(m\_2 s^2 + c\_2 s + k\_2) + m\_2 s^2 (c\_2 s + k\_2)}}
\end{equation}

\begin{equation}
\boxed{x\_2 = \frac{(c\_2s + k\_2)F\_1 + (c\_2s + k\_2)(k\_1 + c\_1 s) x\_0  + (m\_1 s^2 + c\_1 s + k\_1 + c\_2 s + k\_2) F\_2}{(m\_1 s^2 + c\_1 s + k\_1)(m\_2 s^2 + c\_2 s + k\_2) + m\_2 s^2 (c\_2 s + k\_2)}}
\end{equation}

We can see that the effects of \\(x\_0\\) and \\(F\_1\\) are related with a factor \\((c\_1 s + k\_1)\\).

If we are interested by \\(x\_2-x\_1\\):

\begin{equation}
(x\_2 - x1) = \frac{- m\_2 s^2 F\_1 - (m\_2 s^2)(k\_1 + c\_1 s) x\_0  + (m\_1 s^2 + c\_1 s + k\_1) F\_2}{(m\_1 s^2 + c\_1 s + k\_1)(m\_2 s^2 + c\_2 s + k\_2) + m\_2 s^2 (c\_2 s + k\_2)}
\end{equation}

|    | x1                          | x2                         | x2-x1              |
|----|-----------------------------|----------------------------|--------------------|
| x0 | (c1s + k1)(m2s2 + c2s + k2) | (c1s + k1)(c2s + k2)       | - m2s2\*(k1 + c1s) |
| F1 | m2s2 + c2s + k2             | c2s + k2                   | - m2s2             |
| F2 | c2s + k2                    | m1s2 + c1s + k1 + c2s + k2 | m1s2 + c1s + k1    |


### Matlab model {#matlab-model}

```matlab
%% Values for the 2dof Mass-Spring-Damper system
m1 = 5e2; % [kg]
k1 = 2e6; % [N/m]
c1 = 2*0.01*sqrt(m1*k1); % [N/(m/s)]

m2 = 10; % [kg]
k2 = 1e6; % [N/m]
c2 = 2*0.01*sqrt(m2*k2); % [N/(m/s)]
```

```matlab
%% Transfer functions
G_x0_to_x1 = (c1*s + k1)*(m2*s^2 + c2*s + k2)/((m1*s^2 + c1*s + k1)*(m2*s^2 + c2*s + k2) + m2*s^2*(c2*s + k2));
G_F1_to_x1 = (m2*s^2 + c2*s + k2)/((m1*s^2 + c1*s + k1)*(m2*s^2 + c2*s + k2) + m2*s^2*(c2*s + k2));
G_F2_to_x1 = (c2*s + k2)/((m1*s^2 + c1*s + k1)*(m2*s^2 + c2*s + k2) + m2*s^2*(c2*s + k2));

G_x0_to_x2 = (c1*s + k1)*(c2*s + k2)/((m1*s^2 + c1*s + k1)*(m2*s^2 + c2*s + k2) + m2*s^2*(c2*s + k2));
G_F1_to_x2 = (c2*s + k2)/((m1*s^2 + c1*s + k1)*(m2*s^2 + c2*s + k2) + m2*s^2*(c2*s + k2));
G_F2_to_x2 = (m1*s^2 + c1*s + k1 + c2*s + k2)/((m1*s^2 + c1*s + k1)*(m2*s^2 + c2*s + k2) + m2*s^2*(c2*s + k2));

G_x0_to_d2 = -m2*s^2*(c1*s + k1)/((m1*s^2 + c1*s + k1)*(m2*s^2 + c2*s + k2) + m2*s^2*(c2*s + k2));
G_F1_to_d2 = -m2*s^2/((m1*s^2 + c1*s + k1)*(m2*s^2 + c2*s + k2) + m2*s^2*(c2*s + k2));
G_F2_to_d2 = (m1*s^2 + c1*s + k1)/((m1*s^2 + c1*s + k1)*(m2*s^2 + c2*s + k2) + m2*s^2*(c2*s + k2));
```

From [Figure 5](#figure--fig:mass-spring-damper-2dof-x0-bode-plots), we can see that:

-   the low frequency transmissibility is equal to one
-   the high frequency transmissibility to the second mass is smaller than to the first mass

<a id="figure--fig:mass-spring-damper-2dof-x0-bode-plots"></a>

{{< figure src="/ox-hugo/mass_spring_damper_2dof_x0_bode_plots.png" caption="<span class=\"figure-number\">Figure 5: </span>Transfer functions from x0 to x1 and x2 (Transmissibility)" >}}

The transfer function from \\(F\_1\\) to the mass displacements ([Figure 6](#figure--fig:mass-spring-damper-2dof-F1-bode-plots)) has the same shape than the transmissibility ([Figure 5](#figure--fig:mass-spring-damper-2dof-x0-bode-plots)).

However, the low frequency gain is now equal to \\(1/k\_1\\).

<a id="figure--fig:mass-spring-damper-2dof-F1-bode-plots"></a>

{{< figure src="/ox-hugo/mass_spring_damper_2dof_F1_bode_plots.png" caption="<span class=\"figure-number\">Figure 6: </span>Transfer functions from F1 to x1 and x2" >}}

The transfer functions from \\(F\_2\\) to the mass displacements are shown in [Figure 7](#figure--fig:mass-spring-damper-2dof-F2-bode-plots):

-   the motion \\(x\_1\\) is smaller than \\(x\_2\\)

<a id="figure--fig:mass-spring-damper-2dof-F2-bode-plots"></a>

{{< figure src="/ox-hugo/mass_spring_damper_2dof_F2_bode_plots.png" caption="<span class=\"figure-number\">Figure 7: </span>Transfer functions from F2 to x1 and x2" >}}


## Bibliography {#bibliography}

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
</div>
